pub enum Push<'a> {
AllMatchingBranches {
allow_non_fast_forward: bool,
},
Delete {
ref_or_pattern: &'a BStr,
},
Matching {
src: &'a BStr,
dst: &'a BStr,
allow_non_fast_forward: bool,
},
Exclude {
src: &'a BStr,
},
}Expand description
Sources are local ref names, ref patterns, or revision expressions unless specified otherwise. A non-pattern source with an explicit destination is kept without syntax validation, like Git. Destinations are partial or full ref names on the remote side.
Variants
AllMatchingBranches
Push all local branches to the matching destination on the remote, which has to exist to be updated.
Fields
Delete
Delete the destination ref.
Matching
Push the object or objects named by src to dst.
Fields

src: &'a BStrThe source expression to push. Non-pattern expressions with an explicit destination are not syntax-checked.
Ref patterns contain exactly one *, such as refs/heads/*.
Exclude
Exclude a single ref.